@@ -25,6 +25,7 @@
 #' @param by Marginal predictions
 #' + Character vector (max length 3): Names of the categorical predictors to marginalize across.
 #' + 1: x-axis. 2: color. 3: facets.
+#' @param newdata When `newdata` is `NULL`, the grid is determined by the `condition` argument. When `newdata` is not `NULL`, the argument behaves in the same way as in the `predictions()` function.
 #' @param points Number between 0 and 1 which controls the transparency of raw data points. 0 (default) does not display any points.
 #' @param draw `TRUE` returns a `ggplot2` plot. `FALSE` returns a `data.frame` of the underlying data.
 #' @inheritParams plot_slopes
@@ -50,6 +51,7 @@ plot_predictions <- function(model,
                              type = NULL,
                              vcov = NULL,
                              conf_level = 0.95,
+                             wts = NULL,
                              transform = NULL,
                              points = 0,
                              rug = FALSE,
@@ -80,6 +82,9 @@ plot_predictions <- function(model,
     if (!is.null(newdata) && is.null(by)) {
         insight::format_error("The `newdata` argument requires a `by` argument.")
     }
+    if (!is.null(wts) && is.null(by)) {
+        insight::format_error("The `wts` argument requires a `by` argument.")
+    }
     checkmate::assert_character(by, null.ok = TRUE)
 
     # sanity check
@@ -104,6 +109,7 @@ plot_predictions <- function(model,
             conf_level = conf_level,
             transform = transform,
             modeldata = modeldata,
+            wts = wts,
             ...)
     }
 
@@ -122,7 +128,7 @@ plot_predictions <- function(model,
             type = type,
             vcov = vcov,
             conf_level = conf_level,
-            wts = NULL,
+            wts = wts,
             transform = transform,
             newdata = newdata,
             modeldata = modeldata,
