@@ -1,7 +1,5 @@
 sanitize_hypothesis <- function(hypothesis, ...) {
 
-    deprecation_arg(hypothesis, "hypothesis", "lincom", ...) 
-
     checkmate::assert(
         checkmate::check_string(hypothesis, pattern = "="),
         checkmate::check_choice(hypothesis, choices = c("pairwise", "reference", "sequential", "revpairwise", "revreference", "revsequential")),
@@ -9,12 +7,26 @@ sanitize_hypothesis <- function(hypothesis, ...) {
         checkmate::check_matrix(hypothesis),
         checkmate::check_null(hypothesis))
 
+    hnull <- 0
+
     if (isTRUE(checkmate::check_string(hypothesis, pattern = "="))) {
         out <- paste(gsub("=", "-(", hypothesis), ")")
         attr(out, "label") <- hypothesis
-        return(out)
-    } else {
-        return(hypothesis)
+        hypothesis <- out
+
+    } else if (isTRUE(checkmate::check_matrix(hypothesis))) {
+        attr(hypothesis, "label") <- colnames(hypothesis)
+
+    }  else if (isTRUE(checkmate::check_numeric(hypothesis, len = 1))) {
+        hnull <- hypothesis
+        hypothesis <- NULL
     }
 
+    out <- list(
+        "hypothesis" = hypothesis,
+        "hypothesis_null" = hnull
+    )
+
+    return(out)
+
 }
