@@ -14,7 +14,7 @@ yB <- -1 + 3 * xB + rnorm(n / 2, 0, 0.1)
 
 simdat <- data.frame(group_id = group_id, x = c(xA, xB), y = c(yA, yB))
 simdat$group_id <- as.factor(simdat$group_id)
-tmp <<- simdat
+tmp <- simdat
 
 model_additive <- lm(y ~ x + group_id, data = tmp)
 model_interaction <- lm(y ~ x * group_id, data = tmp)
@@ -35,4 +35,8 @@ c2 <- comparisons(model_interaction, variable = "group_id", newdata = tmp)
 c2 <- tidy(c2)
 
 expect_equivalent(g1, c1$estimate)
-expect_equivalent(g2, c2$estimate)
\ No newline at end of file
+expect_equivalent(g2, c2$estimate)
+
+
+
+rm(list = ls())
\ No newline at end of file
