@@ -126,10 +126,12 @@ expect_equivalent(p3$term, c("Contrast A", "Contrast B"))
 
 # marginalmeans: hypothesis complex
 lc <- c(-2, 1, 1, 0, -1, 1)
+mm <- marginal_means(mod, variables = "carb")
+lcmfx <- lc[match(mm$value, sort(unique(mm$value)))]
 em <- emmeans(mod, "carb") 
 em <- emmeans::contrast(em, method = data.frame(custom_contrast = lc))
 em <- data.frame(em)
-mm <- marginal_means(mod, variables = "carb", hypothesis = lc)
+mm <- marginal_means(mod, variables = "carb", hypothesis = lcmfx)
 expect_equivalent(mm$estimate, em$estimate)
 expect_equivalent(mm$std.error, em$SE)
 
