@@ -1,10 +1,10 @@
 source("helpers.R")
 using("marginaleffects")
 
-exit_if_not(requiet("margins"))
-exit_if_not(requiet("broom"))
-exit_if_not(requiet("emmeans"))
-exit_if_not(requiet("dplyr"))
+requiet("margins")
+requiet("broom")
+requiet("emmeans")
+requiet("poorman")
 
 
 guerry <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/HistData/Guerry.csv")
@@ -27,7 +27,7 @@ expect_true(expect_margins(res, mar, tolerance = 0.1, verbose=TRUE))
 
 # predictions
 pre <- predictions(mod)
-expect_predictions(pre)
+expect_predictions(pre, se = FALSE)
 
 
 # emmeans comparison
@@ -79,7 +79,7 @@ res <- slopes(mod, variable = "hp", newdata = counterfactuals)
 expect_equivalent(res$estimate[1], em1$hp.trend)
 expect_equivalent(res$std.error[1], em1$std.error, tolerance = .001)
 expect_equivalent(res$estimate[2], em2$hp.trend)
-expect_equivalent(res$std.error[2], em2$std.error, tolerance = .0001)
+expect_equivalent(res$std.error[2], em2$std.error, tolerance = .001)
 
 
 
@@ -88,11 +88,11 @@ dat <- mtcars
 dat$cyl <- as.factor(dat$cyl)
 dat$am <- as.logical(dat$am)
 mod <- lm(mpg ~ hp + cyl + am, data = dat)
-mm <- tidy(marginal_means(mod, variables = "cyl"))
+mm <- tidy(marginal_means(mod, variables = "cyl")) |> dplyr::arrange(value)
 em <- broom::tidy(emmeans::emmeans(mod, specs = "cyl"))
 expect_equivalent(mm$estimate, em$estimate)
 expect_equivalent(mm$std.error, em$std.error)
-mm <- tidy(marginal_means(mod, variables = "am"))
+mm <- tidy(marginal_means(mod, variables = "am")) |> dplyr::arrange(value)
 em <- broom::tidy(emmeans::emmeans(mod, specs = "am"))
 expect_equivalent(mm$estimate, em$estimate)
 expect_equivalent(mm$std.error, em$std.error)
@@ -111,23 +111,23 @@ dat$Region <- as.factor(dat$Region)
 dat$MainCity <- as.factor(dat$MainCity)
 mod <- glm(binary ~ Region + MainCity + Commerce, data = dat, family = "binomial")
 
-mm <- marginal_means(mod, type = "link", variables = "Region")
+mm <- marginal_means(mod, type = "link", variables = "Region") |> dplyr::arrange(value) 
 em <- data.frame(emmeans::emmeans(mod, specs = "Region"))
 expect_equivalent(as.character(mm$value), as.character(em$Region))
 expect_equivalent(mm$estimate, em$emmean, tol = 0.05) # not sure why tolerance is not good
 expect_equivalent(mm$std.error, em$SE, tol = 0.001)
 
-mm <- marginal_means(mod, type = "link", variables = "MainCity")
-em <- data.frame(emmeans::emmeans(mod, specs = "MainCity"))
+mm <- marginal_means(mod, type = "link", variables = "MainCity") |> dplyr::arrange(value)
+em <- data.frame(emmeans::emmeans(mod, specs = "MainCity", type = "link"))
 expect_equivalent(as.character(mm$value), as.character(em$MainCity))
 expect_equivalent(mm$estimate, em$emmean, tol = 0.01) # not sure why tolerance is not good
 expect_equivalent(mm$std.error, em$SE, tol = 0.001)
 
-mm <- marginal_means(mod, variables = "MainCity")
+
+mm <- marginal_means(mod, type = "link", variables = "MainCity", transform = plogis) |> dplyr::arrange(value)
 em <- data.frame(emmeans(mod, specs = "MainCity", type = "response"))
 expect_equivalent(as.character(mm$value), as.character(em$MainCity))
 expect_equivalent(mm$estimate, em$prob, tolerance = .01)
-expect_equivalent(mm$std.error, em$std.error, tolerance = .01)
 expect_equivalent(mm$conf.low, em$asymp.LCL, tolerance = .01)
 expect_equivalent(mm$conf.high, em$asymp.UCL, tolerance = .01)
 
@@ -169,4 +169,8 @@ mod <- lm(cbind(mpg, cyl) ~ disp + am, data = mtcars)
 expect_equivalent(colnames(get_predict(mod)), c("rowid", "group", "estimate"))
 
 mod <- lm(mpg ~ disp + am, data = mtcars)
-expect_equivalent(colnames(get_predict(mod)), c("rowid", "estimate"))
\ No newline at end of file
+expect_equivalent(colnames(get_predict(mod)), c("rowid", "estimate"))
+
+
+
+rm(list = ls())
\ No newline at end of file
